@@ -4,13 +4,17 @@
 import datetime
 import time
 import uuid
-import commands
+import commands,os
+import sqlite
 import sqlite3
 import pango
-
+import pyDes
+import hashlib          
+import StringIO
 DB_FORMAT = '%Y-%m-%d'
-FRAMEWORK_VERSION = '0.1.2' 
+FRAMEWORK_VERSION = '0.1.3' 
 DB_PATH = '/home/user/.mPIM/mnotes.db'
+DB_IMG_FOLDER = '/home/user/.mPIM/mnotes_img/'
 
 class Database:
         def __init__(self,path=None):
@@ -22,9 +26,14 @@ class Database:
             self.path = '/home/user/.mPIM/mnotes.db'
           try:
             self.db = sqlite3.connect(self.path)
+            self.db.text_factory = str
             self.cursor = self.db.cursor()
-            self._update()
-          except:
+            try:
+              self._update()
+            except:
+              pass
+          except StandardError, e:
+            print e
             print 'Database doesn t exist'
             self._create()
 
@@ -33,7 +42,7 @@ class Database:
           commands.getoutput("mkdir /home/user/.mPIM/")
           self.db = sqlite3.connect(self.path)
           self.cursor = self.db.cursor()
-          self.cursor.execute('CREATE TABLE notes (uuid TEXT PRIMARY KEY, title DATETIME, description TEXT)')
+          self.cursor.execute('CREATE TABLE notes (uuid TEXT PRIMARY KEY, title DATETIME, description TEXT,photo BINARY,draw BINARY)')
           self.db.commit()
           self.cursor.execute('CREATE TABLE db_struct (version TEXT);')
           self.db.commit()
@@ -47,11 +56,20 @@ class Database:
           for version in self.cursor.fetchall():
             v = version
           version = v[0]
-          if version < '0.1.0':
-            self._create()
-          if version < '0.1.1':
-            self.cursor.execute('CREATE TABLE prefs (uuid TEXT PRIMARY KEY, value DATETIME)')
-            self.db.commit()
+          
+          try:
+            if version < '0.1.0':
+              self._create()
+            if version < '0.1.1':
+              self.cursor.execute('CREATE TABLE prefs (uuid TEXT PRIMARY KEY, value DATETIME)')
+              self.db.commit()
+            if version < '0.1.3':
+#              self.cursor.execute('ALTER TABLE notes ADD COLUMN photo BINARY')
+#              self.cursor.execute('ALTER TABLE notes ADD COLUMN draw BINARY')
+              self.db.commit()
+          except:
+            pass
+            
           if version != FRAMEWORK_VERSION:
             self.cursor.execute('UPDATE db_struct set version=?',[FRAMEWORK_VERSION,])
             self.db.commit()
@@ -93,6 +111,9 @@ class Note:
 
             self.title = default_title
             self.description = default_title
+            self.crypted = False
+            self.have_photo = False
+            self.have_draw = False
 
             if suuid=='':
               self.uuid = uuid.uuid4().__str__()
@@ -102,26 +123,76 @@ class Note:
               self.load_from_db(self.uuid)
               self.new = False
 
+        def test_have_photo(self):
+          if os.path.exists(self.get_photo_path())==False:
+            self.photo = False
+          else:
+            self.photo=True
+        def test_have_draw(self):
+          if os.path.exists(self.get_draw_path())==False:
+            self.draw = False
+          else:
+            self.draw=True
+        def get_photo_path(self):
+          if os.path.exists('/home/user/.mPIM/mnotes_img/')==False:
+            commands.getoutput("mkdir /home/user/.mPIM/mnotes_img/")
+          return DB_IMG_FOLDER+'photos_'+self.uuid+'.jpg'
+        def get_draw_path(self):
+          if os.path.exists('/home/user/.mPIM/mnotes_img/')==False:
+            commands.getoutput("mkdir /home/user/.mPIM/mnotes_img/")
+          return DB_IMG_FOLDER+'draw_'+self.uuid+'.jpg'
+
         def load_from_db(self,suuid):
             db = Database(DB_PATH)
-            db.cursor.execute('SELECT title, description FROM notes where uuid="'+suuid+'"')
+            db.cursor.execute('SELECT title, description, crypted FROM notes where uuid="'+suuid+'"')
             for note in db.cursor.fetchall():
               self.description = note[1]
               self.title = note[0]
+              if note[2]==None:
+                self.crypted = False
+              else:
+                self.crypted = (int(note[2])==1)
               self.new = False
+            self.test_have_draw()
+            self.test_have_photo()
             db.close()
 
         def save_to_db(self):
-            self.title = self.description.split('\n')[0]
+            if self.crypted == False:
+              self.title = self.description.split('\n')[0]
             db = Database(DB_PATH)
             if self.new==True:
-              db.cursor.execute('INSERT INTO notes (uuid , title, description ) VALUES(?,?,?);',[self.uuid,self.title,self.description])
+              db.cursor.execute('INSERT INTO notes (uuid , title, description,crypted ) VALUES(?,?,?,?);',[self.uuid,self.title,self.description,int(self.crypted)])
               db.db.commit()
             else:
-              db.cursor.execute('UPDATE notes SET title=?, description=? WHERE uuid=?;',[self.title,self.description,self.uuid])
+              db.cursor.execute('UPDATE notes SET title=?, description=?, crypted=? WHERE uuid=?;',[self.title,self.description,int(self.crypted),self.uuid])
               db.db.commit()
             db.close()
 
+        def encrypt(self,password):
+          digest = hashlib.md5(password).digest()
+          krypt = pyDes.triple_des( digest, pyDes.ECB )
+          mod = len( self.description ) % 8
+          if mod != 0 :
+            self.description = self.description + ''.rjust( 8 - mod, '\0' )
+          self.description = krypt.encrypt(self.description)
+          self.crypted = True
+
+        def get_uncrypted_text(self,password):
+          if self.crypted == False:
+            return self.description
+          else:
+            digest = hashlib.md5(password).digest()
+            krypt = pyDes.triple_des( digest, pyDes.ECB )
+            return str(krypt.decrypt(self.description))
+
+        def decrypt(self,password):
+          if self.crypted == True:
+            digest = hashlib.md5(password).digest()
+            krypt = pyDes.triple_des( digest, pyDes.ECB )
+            self.description = krypt.decrypt(self.description)
+            self.crypted = False
+
         def get_bg_color(self):
           return '#FFFFFF'
 
